OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Úlohy",
    "Important" : "Dôležité",
    "Today" : "Dnes",
    "Week" : "Týždeň",
    "All" : "Všetky",
    "Current" : "Aktuálne",
    "Completed" : "Dokončené",
    "The Tasks app for Nextcloud" : "Aplikácia úloh pre Nextcloud",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "No users or groups" : "Žiadny používatelia alebo skupiny",
    "can edit" : "môže upravovať ",
    "Delete" : "Zmazať",
    "Cancel" : "Zrušiť",
    "Load all completed tasks." : "Načítať všetky ukončené úlohy",
    "Change sort order" : "Zmeniť spôsob zoradenia",
    "Default" : "Predvolené",
    "Due date" : "Termín dokončenia",
    "Sort by due date and summary." : "Zoradiť podľa termínu dokončenia a sumáru.",
    "Start date" : "Dátum začatia",
    "Created date" : "Dátum vytvorenia",
    "Last modified" : "Naposledy upravené",
    "Priority" : "Priorita",
    "Manually" : "Manuálne",
    "Alphabetically" : "Abecedne",
    "Task is completed" : "Úloha je dokončená",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n dokončená úloha","%n dokončené úlohy","%n dokončených úloh","%n dokončených úloh"],
    "Tomorrow" : "Zajtra",
    "Set start date" : "Nastaviť dátum začatia",
    "Set due date" : "Nastaviť do dátumu",
    "All day" : "Celý deň",
    "Task not found!" : "Úloha nebola nájdená!",
    "%s %% completed" : "%s %% ukončené",
    "Edit" : "Upraviť",
    "Download" : "Sťahovanie",
    "Save" : "Uložiť",
    "Add List…" : "Pridať zoznam",
    "New List" : "Nový zoznam",
    "The name \"%s\" is already used." : "Názov \"%s\" je už použitý.",
    "An empty name is not allowed." : "Prázdny názov nie je povolený",
    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "Táto operácia odstráni kalendár \"%s\" a všetky jeho udalosti a úlohy.",
    "Settings" : "Nastavenia",
    "Visibility of Smart Collections" : "Viditeľnosť inteligentných kolekcií",
    "Hidden" : "Skryté",
    "Visible" : "Viditeľné",
    "Automatic" : "Automaticky"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
